<!-- Logo: Original in light background and white-logo in dark background -->
<picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/Quansight/ragna/main/docs/assets/brand/logo-lockup-vertical/logo-lockup-vertical-white.png">
    <img src="https://raw.githubusercontent.com/Quansight/ragna/main/docs/assets/brand/logo-lockup-vertical/logo-lockup-vertical.png" alt="Ragna logo" width=30%/>
</picture>

A RAG orchestration framework.

---

<!-- Badge table with useful links -->
<table>
<tr>
    <th>Project</th>
    <td>
        <a href="https://pypi.org/project/Ragna/">
            <img src="https://img.shields.io/pypi/v/ragna?colorA=1F2636&colorB=DF5538"
         alt="PyPI" />
        </a>
    </td>
    <td>
        <a href="https://ragna.chat">
            <img src="https://img.shields.io/badge/documentation-ragna.chat-gray.svg?colorA=1F2636&colorB=DF5538"
         alt="Documentation" />
        </a>
    </td>
</tr>
<tr>
    <th>Community</th>
    <td>
        <a href="https://github.com/Quansight.ragna/discussions">
            <img src="https://img.shields.io/badge/support-GitHub_discussions-gray.svg?colorA=1F2636&colorB=3C8D89"
         alt="GH Discussions" />
        </a>
    </td>
    <td>
        <a href="https://github.com/Quansight.ragna/issues/new/choose/">
            <img src="https://img.shields.io/badge/bugs/features-GitHub_issues-gray.svg?colorA=1F2636&colorB=3C8D89"
         alt="Issues" />
        </a>
    </td>
</tr>
<tr>
</tr>
</table>

## Get started ⛵️

<!-- Link to documentation pages to avoid keeping README + Docs in sync -->

Check out the Ragna documentation to get started:

- [Installation steps](https://ragna.chat/en/stable/install/)
- Tutorials
  - [Python API](https://ragna.chat/en/stable/tutorials/python-api/)
  - [REST API](https://ragna.chat/en/stable/tutorials/rest-api/)
  - [Web application](https://ragna.chat/en/stable/tutorials/web-app/)
- [Frequently asked questions](https://ragna.chat/en/stable/references/faq/)
- [Contribution guidelines](https://ragna.chat/en/stable/community/contribute/)
- [Changelog](https://ragna.chat/en/stable/references/changelog/)

## Code of Conduct 📜

This repository is governed by the
[Quansight Repository Code of Conduct](https://github.com/Quansight/.github/blob/master/CODE_OF_CONDUCT.md).
